"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.config = void 0;
exports.loadConfig = loadConfig;
const dotenv_1 = __importDefault(require("dotenv"));
// Load environment variables from .env file
dotenv_1.default.config();
/**
 * Loads and validates the configuration from environment variables
 * @returns The validated configuration object
 * @throws Error if required configuration is missing
 */
function loadConfig() {
    // Validate required environment variables
    const requiredEnvVars = [
        'JIRA_HOST',
        'JIRA_USERNAME',
        'JIRA_API_TOKEN',
        'JIRA_FIGMA_FIELD_NAME',
        'FIGMA_ACCESS_TOKEN'
    ];
    const missingVars = requiredEnvVars.filter(varName => !process.env[varName]);
    if (missingVars.length > 0) {
        throw new Error(`Missing required environment variables: ${missingVars.join(', ')}`);
    }
    // Create and return the config object
    return {
        jira: {
            host: process.env.JIRA_HOST,
            username: process.env.JIRA_USERNAME,
            apiToken: process.env.JIRA_API_TOKEN,
            figmaFieldName: process.env.JIRA_FIGMA_FIELD_NAME
        },
        figma: {
            accessToken: process.env.FIGMA_ACCESS_TOKEN
        },
        server: {
            port: parseInt(process.env.PORT || '3000', 10),
            cacheTTL: parseInt(process.env.CACHE_TTL || '3600', 10)
        }
    };
}
// Export the singleton config instance
exports.config = loadConfig();
//# sourceMappingURL=index.js.map