"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const jira_figma_mcp_server_1 = require("./mcp/jira-figma-mcp-server");
const express_1 = __importDefault(require("express"));
/**
 * Main entry point for the Jira-Figma MCP
 */
async function main() {
    try {
        console.log('Starting Jira-Figma MCP...');
        console.log(`Jira instance: ${config_1.config.jira.host}`);
        console.log('Figma API access configured');
        // Create the MCP server
        const mcpServer = (0, jira_figma_mcp_server_1.createJiraFigmaMcpServer)();
        // Determine if we're running in stdio mode or http server mode
        const isStdioMode = process.argv.includes('--stdio');
        if (isStdioMode) {
            console.log('Running in stdio mode for direct AI integration...');
            // Add stdio transport for terminal/script integration
            mcpServer.addStdioTransport();
        }
        else {
            console.log('Running in HTTP/SSE mode for web-based AI integration...');
            // Create Express app
            const app = (0, express_1.default)();
            // Add HTTP transport with SSE for web-based integration
            mcpServer.addHttpTransport(app);
            // Start the HTTP server
            app.listen(config_1.config.server.port, () => {
                console.log(`Jira-Figma MCP server running on port ${config_1.config.server.port}`);
                console.log(`MCP endpoints available at:`);
                console.log(`- SSE: http://localhost:${config_1.config.server.port}/mcp/sse`);
                console.log(`- Messages: http://localhost:${config_1.config.server.port}/mcp/messages`);
            });
        }
        // Start the MCP server
        await mcpServer.start();
    }
    catch (error) {
        console.error('Failed to start MCP:', error);
        process.exit(1);
    }
}
// Run the MCP
main().catch(error => {
    console.error('Unhandled error:', error);
    process.exit(1);
});
//# sourceMappingURL=index.js.map