import express from "express";
/**
 * MCP Server that provides tools for interacting with Jira and Figma
 */
export declare class JiraFigmaMcpServer {
    private server;
    private sseTransport;
    private jiraService;
    private figmaService;
    private figmaUrlRegex;
    constructor();
    /**
     * Register all MCP tools
     */
    private registerTools;
    /**
     * Register Jira-specific tools
     */
    private registerJiraTools;
    /**
     * Register Figma-specific tools
     */
    private registerFigmaTools;
    /**
     * Register tools that link Jira and Figma data
     */
    private registerLinkingTools;
    /**
     * Helper function to extract text from rich text content
     * @param content Rich text content object
     * @returns Extracted plain text
     */
    private extractText;
    /**
     * Clean a URL by handling escape sequences
     * @param url URL to clean
     * @returns Cleaned URL
     */
    private cleanUrl;
    /**
     * Parse a Figma URL to extract fileKey and nodeId
     * @param url Figma URL to parse
     * @returns Parsed URL info or null if invalid
     */
    private parseFigmaUrl;
    /**
     * Extract all Figma URLs from a Jira ticket
     * @param ticket The Jira API response
     * @returns Array of parsed Figma URLs
     */
    private extractFigmaUrlsFromTicket;
    /**
     * Connect to a transport mechanism
     */
    connect(transport: any): Promise<void>;
    /**
     * Add HTTP transport for SSE connections
     * @param app Express app to attach to
     * @param ssePath SSE endpoint path
     * @param messagePath Message endpoint path
     */
    addHttpTransport(app: express.Application, ssePath?: string, messagePath?: string): void;
    /**
     * Add stdio transport for terminal/CLI use
     */
    addStdioTransport(): void;
    /**
     * Start listening on the configured transports
     */
    start(): Promise<void>;
}
export declare function createJiraFigmaMcpServer(): JiraFigmaMcpServer;
