import { SimplifiedDesign } from '../utils/figma-helpers';
/**
 * Represents a Jira ticket with essential information
 */
export interface Ticket {
    id: string;
    key: string;
    summary: string;
    description?: string;
    status: string;
    figmaLink: string;
}
/**
 * Information about a Figma URL
 */
export interface FigmaUrlInfo {
    fileKey: string;
    nodeId?: string;
    title?: string;
    /**
     * For non-URL references to Figma designs, stores the textual reference
     */
    textReference?: string;
}
/**
 * Information about a Jira ticket
 */
export interface JiraTicket {
    key: string;
    summary: string;
    description?: string;
    status: string;
    priority?: string;
    assignee?: string;
    figmaLink?: string;
    created: string;
    updated: string;
}
/**
 * Response from Figma API for design information
 */
export interface DesignInfo {
    name: string;
    lastModified: string;
    version: string;
    document: any;
    components?: any;
    styles?: any;
    [key: string]: any;
    /**
     * Simplified version of the design structure
     * Easier to use for AI systems and code generation
     */
    simplified?: SimplifiedDesign;
}
/**
 * Configuration for the MCP
 */
export interface MCPConfig {
    jira: {
        host: string;
        username: string;
        apiToken: string;
        figmaFieldName: string;
    };
    figma: {
        accessToken: string;
    };
    server: {
        port: number;
        cacheTTL: number;
    };
}
/**
 * Error response structure
 */
export interface ErrorResponse {
    error: string;
    message: string;
    statusCode: number;
}
