import { SimplifiedDesign } from "../simplify-node-response";
export interface FigmaError {
    status: number;
    err: string;
}
type FetchImageParams = {
    /**
     * The Node in Figma that will either be rendered or have its background image downloaded
     */
    nodeId: string;
    /**
     * The local file name to save the image
     */
    fileName: string;
    /**
     * The file mimetype for the image
     */
    fileType: "png" | "svg";
};
type FetchImageFillParams = Omit<FetchImageParams, "fileType"> & {
    /**
     * Required to grab the background image when an image is used as a fill
     */
    imageRef: string;
};
export declare class FigmaService {
    private readonly apiKey;
    private readonly baseUrl;
    constructor(apiKey: string);
    private request;
    getImageFills(fileKey: string, nodes: FetchImageFillParams[], localPath: string): Promise<string[]>;
    getImages(fileKey: string, nodes: FetchImageParams[], localPath: string): Promise<string[]>;
    getFile(fileKey: string, depth?: number): Promise<SimplifiedDesign>;
    getNode(fileKey: string, nodeId: string, depth?: number): Promise<SimplifiedDesign>;
}
export {};
