"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FigmaService = void 0;
const axios_1 = __importStar(require("axios"));
const fs_1 = __importDefault(require("fs"));
const simplify_node_response_1 = require("../simplify-node-response");
const common_1 = require("../../utils/common");
class FigmaService {
    constructor(apiKey) {
        this.baseUrl = "https://api.figma.com/v1";
        this.apiKey = apiKey;
    }
    async request(endpoint) {
        try {
            console.log(`Calling ${this.baseUrl}${endpoint}`);
            const response = await axios_1.default.get(`${this.baseUrl}${endpoint}`, {
                headers: {
                    "X-Figma-Token": this.apiKey,
                },
            });
            return response.data;
        }
        catch (error) {
            if (error instanceof axios_1.AxiosError && error.response) {
                throw {
                    status: error.response.status,
                    err: error.response.data.err || "Unknown error",
                };
            }
            throw new Error("Failed to make request to Figma API");
        }
    }
    async getImageFills(fileKey, nodes, localPath) {
        if (nodes.length === 0)
            return [];
        let promises = [];
        const endpoint = `/files/${fileKey}/images`;
        const file = await this.request(endpoint);
        const { images = {} } = file.meta;
        promises = nodes.map(async ({ imageRef, fileName }) => {
            const imageUrl = images[imageRef];
            if (!imageUrl) {
                return "";
            }
            return (0, common_1.downloadFigmaImage)(fileName, localPath, imageUrl);
        });
        return Promise.all(promises);
    }
    async getImages(fileKey, nodes, localPath) {
        const pngIds = nodes.filter(({ fileType }) => fileType === "png").map(({ nodeId }) => nodeId);
        const pngFiles = pngIds.length > 0
            ? this.request(`/images/${fileKey}?ids=${pngIds.join(",")}&scale=2&format=png`).then(({ images = {} }) => images)
            : {};
        const svgIds = nodes.filter(({ fileType }) => fileType === "svg").map(({ nodeId }) => nodeId);
        const svgFiles = svgIds.length > 0
            ? this.request(`/images/${fileKey}?ids=${svgIds.join(",")}&scale=2&format=svg`).then(({ images = {} }) => images)
            : {};
        const files = await Promise.all([pngFiles, svgFiles]).then(([f, l]) => ({ ...f, ...l }));
        const downloads = nodes
            .map(({ nodeId, fileName }) => {
            const imageUrl = files[nodeId];
            if (imageUrl) {
                return (0, common_1.downloadFigmaImage)(fileName, localPath, imageUrl);
            }
            return false;
        })
            .filter((url) => !!url);
        return Promise.all(downloads);
    }
    async getFile(fileKey, depth) {
        try {
            const endpoint = `/files/${fileKey}${depth ? `?depth=${depth}` : ""}`;
            console.log(`Retrieving Figma file: ${fileKey} (depth: ${depth ?? "default"})`);
            const response = await this.request(endpoint);
            console.log("Got response");
            const simplifiedResponse = (0, simplify_node_response_1.parseFigmaResponse)(response);
            writeLogs("figma-raw.json", response);
            writeLogs("figma-simplified.json", simplifiedResponse);
            return simplifiedResponse;
        }
        catch (e) {
            console.error("Failed to get file:", e);
            throw e;
        }
    }
    async getNode(fileKey, nodeId, depth) {
        try {
            const endpoint = `/files/${fileKey}/nodes?ids=${nodeId}${depth ? `&depth=${depth}` : ""}`;
            console.log(`Retrieving Figma node: ${nodeId} from file ${fileKey} (depth: ${depth ?? "default"})`);
            const response = await this.request(endpoint);
            writeLogs("figma-raw.json", response);
            const simplifiedResponse = (0, simplify_node_response_1.parseFigmaResponse)(response);
            writeLogs("figma-simplified.json", simplifiedResponse);
            return simplifiedResponse;
        }
        catch (e) {
            console.error(`Failed to get node ${nodeId} from file ${fileKey}:`, e);
            throw e;
        }
    }
}
exports.FigmaService = FigmaService;
function writeLogs(name, value) {
    try {
        if (process.env.NODE_ENV !== "development")
            return;
        const logsDir = "logs";
        try {
            fs_1.default.accessSync(process.cwd(), fs_1.default.constants.W_OK);
        }
        catch (error) {
            console.log("Failed to write logs:", error);
            return;
        }
        if (!fs_1.default.existsSync(logsDir)) {
            fs_1.default.mkdirSync(logsDir);
        }
        fs_1.default.writeFileSync(`${logsDir}/${name}`, JSON.stringify(value, null, 2));
    }
    catch (error) {
        console.debug("Failed to write logs:", error);
    }
}
//# sourceMappingURL=figma-service.js.map