import { Ticket } from '../../models/types';
/**
 * Service for interacting with Jira API
 */
export declare class JiraService {
    private client;
    private figmaFieldName;
    constructor();
    /**
     * Retrieves a list of Jira tickets based on project and status
     * @param project The Jira project key
     * @param status The ticket status to filter by (optional)
     * @returns Array of ticket objects with figma links
     */
    listTickets(project: string, status?: string): Promise<Ticket[]>;
    /**
     * Retrieves a specific Jira ticket by ID
     * @param ticketId The Jira ticket ID or key
     * @returns Ticket object with figma link
     */
    getTicket(ticketId: string): Promise<Ticket>;
    /**
     * Transforms Jira API response to our ticket model
     * @param issues Array of Jira issues from API
     * @returns Array of transformed ticket objects
     */
    private transformTickets;
    /**
     * Transforms a single Jira issue to our ticket model
     * @param issue Jira issue from API
     * @returns Transformed ticket object
     */
    private transformTicket;
}
export declare const jiraService: JiraService;
