"use strict";
/**
 * Test script for demonstrating MCP stdio mode
 *
 * Run with:
 * - Print requests: npx ts-node src/tests/mcp-stdio-test.ts
 * - Interactive mode: npx ts-node src/tests/mcp-stdio-test.ts --interactive
 * - Pipe to MCP: npx ts-node src/tests/mcp-stdio-test.ts | node dist/index.js --stdio
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
const readline = __importStar(require("readline"));
// Helper function to create a JSON-RPC style request
function createRequest(id, method, params) {
    return JSON.stringify({
        jsonrpc: '2.0',
        id,
        method,
        params
    });
}
// Sample requests to demonstrate MCP interaction
const requests = [
    // Get available tools
    createRequest('1', 'rpc.discover', {}),
    // Get a specific ticket
    createRequest('2', 'get_ticket', {
        ticketId: 'DEMO-123'
    }),
    // Standard MCP tool: Get Figma data
    createRequest('3', 'mcp__get_figma_data', {
        fileKey: 'abcdefghijk',
        depth: 2
    }),
    // Linking tool: Get designs for a ticket
    createRequest('4', 'get_designs_for_ticket', {
        ticket_id: 'DEMO-123',
        depth: 2
    })
];
// Function to run the script in interactive mode
function runInteractive() {
    const rl = readline.createInterface({
        input: process.stdin,
        output: process.stdout
    });
    console.log('=== Jira-Figma MCP Interactive Test ===');
    console.log('Choose a request to send:');
    console.log('1. Discover available tools');
    console.log('2. Get a specific ticket');
    console.log('3. MCP: Get Figma data');
    console.log('4. Get designs for a ticket');
    console.log('q. Quit');
    rl.question('Enter your choice: ', (choice) => {
        if (choice === 'q') {
            rl.close();
            return;
        }
        const index = parseInt(choice, 10) - 1;
        if (index >= 0 && index < requests.length) {
            console.log('\nSending:', requests[index]);
            console.log('\nCopy this request to the MCP server running in stdio mode');
            rl.close();
        }
        else {
            console.log('Invalid choice');
            rl.close();
        }
    });
}
// Helper function to explain the different types of requests
function printRequestCategories() {
    console.log('\n=== Request Categories ===');
    console.log('1. Basic MCP Interaction (#1)');
    console.log('2. Jira Integration (#2)');
    console.log('3. Standard MCP Tools for Figma (#3)');
    console.log('4. Linking Jira and Figma (#4)');
}
// Helper function to print usage instructions
function printUsageInstructions() {
    console.log('\n=== Usage ===');
    console.log('1. Start the MCP server in stdio mode: yarn start:stdio');
    console.log('2. Copy and paste these requests into the MCP server');
    console.log('3. Or run in interactive mode: npx ts-node src/tests/mcp-stdio-test.ts --interactive');
    console.log('4. Or pipe to MCP: npx ts-node src/tests/mcp-stdio-test.ts | node dist/index.js --stdio');
    console.log('\nNote: When using image download tools, ensure you have valid Figma file keys and node IDs.');
}
// Main script
if (process.argv.includes('--interactive')) {
    runInteractive();
}
else {
    // Print the requests for easy copying or piping
    console.log('=== Jira-Figma MCP Test Requests ===');
    requests.forEach((req, index) => {
        console.log(`\n--- Request #${index + 1} ---`);
        console.log(req);
    });
    printRequestCategories();
    printUsageInstructions();
}
//# sourceMappingURL=mcp-stdio-test.js.map