import { ErrorResponse } from '../models/types';
/**
 * Custom error class for API errors
 */
export declare class APIError extends Error {
    statusCode: number;
    constructor(message: string, statusCode?: number);
    /**
     * Converts the error to a standardized response object
     */
    toResponse(): ErrorResponse;
}
/**
 * Error class for Jira-specific errors
 */
export declare class JiraError extends APIError {
    constructor(message: string, statusCode?: number);
}
/**
 * Error class for Figma-specific errors
 */
export declare class FigmaError extends APIError {
    constructor(message: string, statusCode?: number);
}
/**
 * Handler function to format error responses
 * @param error The error to format
 * @returns Standardized error response
 */
export declare function handleError(error: unknown): ErrorResponse;
