"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FigmaError = exports.JiraError = exports.APIError = void 0;
exports.handleError = handleError;
/**
 * Custom error class for API errors
 */
class APIError extends Error {
    constructor(message, statusCode = 500) {
        super(message);
        this.name = 'APIError';
        this.statusCode = statusCode;
    }
    /**
     * Converts the error to a standardized response object
     */
    toResponse() {
        return {
            error: this.name,
            message: this.message,
            statusCode: this.statusCode
        };
    }
}
exports.APIError = APIError;
/**
 * Error class for Jira-specific errors
 */
class JiraError extends APIError {
    constructor(message, statusCode = 400) {
        super(message, statusCode);
        this.name = 'JiraError';
    }
}
exports.JiraError = JiraError;
/**
 * Error class for Figma-specific errors
 */
class FigmaError extends APIError {
    constructor(message, statusCode = 400) {
        super(message, statusCode);
        this.name = 'FigmaError';
    }
}
exports.FigmaError = FigmaError;
/**
 * Handler function to format error responses
 * @param error The error to format
 * @returns Standardized error response
 */
function handleError(error) {
    if (error instanceof APIError) {
        return error.toResponse();
    }
    if (error instanceof Error) {
        return {
            error: error.name || 'UnknownError',
            message: error.message || 'An unknown error occurred',
            statusCode: 500
        };
    }
    return {
        error: 'UnknownError',
        message: String(error) || 'An unknown error occurred',
        statusCode: 500
    };
}
//# sourceMappingURL=errors.js.map