import { Node as FigmaDocumentNode, StrokeWeights } from "@figma/rest-api-spec";
/**
 * Type guard to check if a property exists on an object
 */
export declare function hasValue<K extends string, T extends object>(key: K, obj: T, validator?: (value: any) => boolean): obj is T & Record<K, unknown>;
/**
 * Type guard to check if a node is a Frame
 */
export declare function isFrame(node: FigmaDocumentNode): boolean;
/**
 * Type guard to check if a node has layout properties
 */
export declare function isLayout(node: FigmaDocumentNode): boolean;
/**
 * Type guard to check if an object has a specific rectangle property
 */
export declare function isRectangle<K extends string, T extends object>(key: K, obj: T): obj is T & Record<K, {
    x: number;
    y: number;
    width: number;
    height: number;
}>;
/**
 * Type guard to check if a value is a StrokeWeights object
 */
export declare function isStrokeWeights(value: any): value is StrokeWeights;
/**
 * Type guard to check if a value is truthy
 */
export declare function isTruthy(value: any): boolean;
/**
 * Type guard to check if a value is a rectangle corner radii array
 */
export declare function isRectangleCornerRadii(value: any): value is [number, number, number, number];
