"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasValue = hasValue;
exports.isFrame = isFrame;
exports.isLayout = isLayout;
exports.isRectangle = isRectangle;
exports.isStrokeWeights = isStrokeWeights;
exports.isTruthy = isTruthy;
exports.isRectangleCornerRadii = isRectangleCornerRadii;
/**
 * Type guard to check if a property exists on an object
 */
function hasValue(key, obj, validator) {
    if (!(key in obj))
        return false;
    if (!validator)
        return true;
    return validator(obj[key]);
}
/**
 * Type guard to check if a node is a Frame
 */
function isFrame(node) {
    return (node.type === "FRAME" ||
        node.type === "COMPONENT" ||
        node.type === "COMPONENT_SET" ||
        node.type === "INSTANCE");
}
/**
 * Type guard to check if a node has layout properties
 */
function isLayout(node) {
    return ("layoutAlign" in node ||
        "layoutGrow" in node ||
        "layoutPositioning" in node ||
        "layoutSizingHorizontal" in node ||
        "layoutSizingVertical" in node);
}
/**
 * Type guard to check if an object has a specific rectangle property
 */
function isRectangle(key, obj) {
    if (!(key in obj))
        return false;
    const rect = obj[key];
    return (rect &&
        typeof rect === "object" &&
        "x" in rect &&
        "y" in rect &&
        "width" in rect &&
        "height" in rect);
}
/**
 * Type guard to check if a value is a StrokeWeights object
 */
function isStrokeWeights(value) {
    return (value &&
        typeof value === "object" &&
        "top" in value &&
        "right" in value &&
        "bottom" in value &&
        "left" in value);
}
/**
 * Type guard to check if a value is truthy
 */
function isTruthy(value) {
    return !!value;
}
/**
 * Type guard to check if a value is a rectangle corner radii array
 */
function isRectangleCornerRadii(value) {
    return (Array.isArray(value) &&
        value.length === 4 &&
        value.every(r => typeof r === 'number'));
}
//# sourceMappingURL=identity.js.map